==> cuteradio_0.2.0.tar.gz: cuteradio-0.2.0/src/maemo5/editpodcastdialog.cpp <==
/*
 * Copyright (C) 2014 Stuart Howarth <showarth@marxoft.co.uk>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms and conditions of the GNU Lesser General Public License,
 * version 3, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
 */

#include <QLineEdit>
#include <QTextEdit>
#include <QLabel>
#include <QDialogButtonBox>
#include <QGridLayout>
#include "editpodcastdialog.h"
#include "scrollarea.h"
#include "../base/station.h"
#include "../base/database.h"
#include "../base/logodownloader.h"
#include "../base/utils.h"

EditPodcastDialog::EditPodcastDialog(Station *podcast, QWidget *parent) :
    AbstractDialog(parent),
    m_podcast(podcast),
    m_titleEdit(new QLineEdit(podcast->title(), this)),
    m_logoEdit(new QLineEdit(podcast->logo().toString(), this)),
    m_sourceEdit(new QLineEdit(podcast->source().toString(), this)),
    m_descriptionEdit(new QTextEdit(podcast->description(), this)),
    m_scrollArea(new ScrollArea(this)),
    m_buttonBox(new QDialogButtonBox(QDialogButtonBox::Ok, Qt::Vertical, this)),
    m_grid(new QGridLayout(this))
{
    this->setWindowTitle(tr("Edit podcast"));

    QWidget *scrollWidget = new QWidget(m_scrollArea);
    QVBoxLayout *vbox = new QVBoxLayout(scrollWidget);
    vbox->setContentsMargins(0, 0, 0, 0);
    vbox->addWidget(new QLabel(tr("Title"), this));
    vbox->addWidget(m_titleEdit);
    vbox->addWidget(new QLabel(tr("Description"), this));
    vbox->addWidget(m_descriptionEdit);
    vbox->addWidget(new QLabel(tr("Logo"), this));
    vbox->addWidget(m_logoEdit);
    vbox->addWidget(new QLabel(tr("Source"), this));
    vbox->addWidget(m_sourceEdit);

    m_scrollArea->setWidgetResizable(true);
    m_scrollArea->setWidget(scrollWidget);
    m_scrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
    m_scrollArea->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Preferred);

    m_buttonBox->setEnabled((!m_titleEdit->text().isEmpty()) && (!m_sourceEdit->text().isEmpty()));

    this->connect(m_titleEdit, SIGNAL(textChanged(QString)), this, SLOT(onTitleChanged(QString)));
    this->connect(m_sourceEdit, SIGNAL(textChanged(QString)), this, SLOT(onSourceChanged(QString)));
    this->connect(m_buttonBox, SIGNAL(accepted()), this, SLOT(editPodcast()));

    this->onOrientationChanged();
}

void EditPodcastDialog::setLandscapeLayout() {
    this->setFixedHeight(340);
    m_buttonBox->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Preferred);

    if (m_grid->isEmpty()) {
        m_grid->addWidget(m_scrollArea, 0, 0);
        m_grid->addWidget(m_buttonBox, 0, 1, Qt::AlignBottom);
    }
    else {
        m_grid->removeWidget(m_buttonBox);
        m_grid->addWidget(m_buttonBox, 0, 1, Qt::AlignBottom);
    }
}

void EditPodcastDialog::setPortraitLayout() {
    this->setFixedHeight(600);
    m_buttonBox->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);

    if (m_grid->isEmpty()) {
        m_grid->addWidget(m_scrollArea, 0, 0);
        m_grid->addWidget(m_buttonBox, 1, 0);
    }
    else {
        m_grid->removeWidget(m_buttonBox);
        m_grid->addWidget(m_buttonBox, 1, 0);
    }
}

void EditPodcastDialog::onTitleChanged(const QString &title) {
    m_buttonBox->setEnabled((!title.isEmpty()) && (!m_sourceEdit->text().isEmpty()));
}

void EditPodcastDialog::onSourceChanged(const QString &source) {
    m_buttonBox->setEnabled((!m_titleEdit->text().isEmpty()) && (!source.isEmpty()));
}

void EditPodcastDialog::editPodcast() {
    if (m_podcast) {
        if (!m_logoEdit->text().startsWith("http")) {
            QVariantMap properties;
            properties["title"] = m_titleEdit->text();
            properties["description"] = m_descriptionEdit->toPlainText();
            properties["logo"] = m_logoEdit->text();
            properties["source"] = m_sourceEdit->text();

            Database::asyncUpdatePodcast(m_podcast->id(), properties);

            this->accept();
        }
        else {
            this->toggleBusy(true);

            LogoDownloader *downloader = new LogoDownloader(QUrl(m_logoEdit->text()), QString("%1%2.png").arg(Utils::logoPath()).arg(m_podcast->id()), this);
            this->connect(downloader, SIGNAL(finished(LogoDownloader*)), this, SLOT(onLogoDownloaderFinished(LogoDownloader*)));
        }
    }
    else {
        this->reject();
    }
}

void EditPodcastDialog::onLogoDownloaderFinished(LogoDownloader *downloader) {
    if (m_podcast) {
        QVariantMap properties;
        properties["title"] = m_titleEdit->text();
        properties["description"] = m_descriptionEdit->toPlainText();
        properties["logo"] = QUrl(downloader->localPath());
        properties["source"] = m_sourceEdit->text();

        Database::asyncUpdatePodcast(m_podcast->id(), properties);
    }

    this->toggleBusy(false);
    this->accept();
}

==> cuteradio_0.2.1.tar.gz: cuteradio-0.2.1/src/maemo5/editpodcastdialog.cpp <==
/*
 * Copyright (C) 2014 Stuart Howarth <showarth@marxoft.co.uk>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms and conditions of the GNU Lesser General Public License,
 * version 3, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
 */

#include <QLineEdit>
#include <QTextEdit>
#include <QLabel>
#include <QRegExpValidator>
#include <QDialogButtonBox>
#include <QGridLayout>
#include "editpodcastdialog.h"
#include "scrollarea.h"
#include "../base/station.h"
#include "../base/database.h"
#include "../base/logodownloader.h"
#include "../base/utils.h"

EditPodcastDialog::EditPodcastDialog(Station *podcast, QWidget *parent) :
    AbstractDialog(parent),
    m_podcast(podcast),
    m_titleEdit(new QLineEdit(podcast->title(), this)),
    m_logoEdit(new QLineEdit(podcast->logo().toString(), this)),
    m_sourceEdit(new QLineEdit(podcast->source().toString(), this)),
    m_descriptionEdit(new QTextEdit(podcast->description(), this)),
    m_scrollArea(new ScrollArea(this)),
    m_buttonBox(new QDialogButtonBox(QDialogButtonBox::Ok, Qt::Vertical, this)),
    m_grid(new QGridLayout(this))
{
    this->setWindowTitle(tr("Edit podcast"));

    QWidget *scrollWidget = new QWidget(m_scrollArea);
    QVBoxLayout *vbox = new QVBoxLayout(scrollWidget);
    vbox->setContentsMargins(0, 0, 0, 0);
    vbox->addWidget(new QLabel(tr("Title"), this));
    vbox->addWidget(m_titleEdit);
    vbox->addWidget(new QLabel(tr("Description"), this));
    vbox->addWidget(m_descriptionEdit);
    vbox->addWidget(new QLabel(tr("Logo"), this));
    vbox->addWidget(m_logoEdit);
    vbox->addWidget(new QLabel(tr("Source"), this));
    vbox->addWidget(m_sourceEdit);

    m_titleEdit->setValidator(new QRegExpValidator(QRegExp("^\\S.+"), m_titleEdit));
    m_sourceEdit->setValidator(new QRegExpValidator(QRegExp("^http(s|)://\\S+"), m_sourceEdit));

    m_scrollArea->setWidgetResizable(true);
    m_scrollArea->setWidget(scrollWidget);
    m_scrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
    m_scrollArea->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Preferred);

    this->connect(m_titleEdit, SIGNAL(textChanged(QString)), this, SLOT(onTitleChanged()));
    this->connect(m_sourceEdit, SIGNAL(textChanged(QString)), this, SLOT(onSourceChanged()));
    this->connect(m_buttonBox, SIGNAL(accepted()), this, SLOT(editPodcast()));

    this->onOrientationChanged();
    this->onTitleChanged();
}

void EditPodcastDialog::setLandscapeLayout() {
    this->setFixedHeight(340);
    m_buttonBox->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Preferred);

    if (m_grid->isEmpty()) {
        m_grid->addWidget(m_scrollArea, 0, 0);
        m_grid->addWidget(m_buttonBox, 0, 1, Qt::AlignBottom);
    }
    else {
        m_grid->removeWidget(m_buttonBox);
        m_grid->addWidget(m_buttonBox, 0, 1, Qt::AlignBottom);
    }
}

void EditPodcastDialog::setPortraitLayout() {
    this->setFixedHeight(600);
    m_buttonBox->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);

    if (m_grid->isEmpty()) {
        m_grid->addWidget(m_scrollArea, 0, 0);
        m_grid->addWidget(m_buttonBox, 1, 0);
    }
    else {
        m_grid->removeWidget(m_buttonBox);
        m_grid->addWidget(m_buttonBox, 1, 0);
    }
}

void EditPodcastDialog::toggleBusy(bool busy) {
    AbstractDialog::toggleBusy(busy);
    m_scrollArea->setEnabled(!busy);
    m_buttonBox->setEnabled(!busy);
}

void EditPodcastDialog::onTitleChanged() {
    m_buttonBox->setEnabled((m_titleEdit->hasAcceptableInput()) && (m_sourceEdit->hasAcceptableInput()));
}

void EditPodcastDialog::onSourceChanged() {
    m_buttonBox->setEnabled((m_titleEdit->hasAcceptableInput()) && (m_sourceEdit->hasAcceptableInput()));
}

void EditPodcastDialog::editPodcast() {
    if (m_podcast) {
        if (!m_logoEdit->text().startsWith("http")) {
            QVariantMap properties;
            properties["title"] = m_titleEdit->text();
            properties["description"] = m_descriptionEdit->toPlainText();
            properties["logo"] = m_logoEdit->text();
            properties["source"] = m_sourceEdit->text();

            Database::asyncUpdatePodcast(m_podcast->id(), properties);

            this->accept();
        }
        else {
            this->toggleBusy(true);

            LogoDownloader *downloader = new LogoDownloader(QUrl(m_logoEdit->text()), QString("%1%2.png").arg(Utils::logoPath()).arg(m_podcast->id()), this);
            this->connect(downloader, SIGNAL(finished(LogoDownloader*)), this, SLOT(onLogoDownloaderFinished(LogoDownloader*)));
        }
    }
    else {
        this->reject();
    }
}

void EditPodcastDialog::onLogoDownloaderFinished(LogoDownloader *downloader) {
    if (m_podcast) {
        QVariantMap properties;
        properties["title"] = m_titleEdit->text();
        properties["description"] = m_descriptionEdit->toPlainText();
        properties["logo"] = QUrl(downloader->localPath());
        properties["source"] = m_sourceEdit->text();

        Database::asyncUpdatePodcast(m_podcast->id(), properties);
    }

    this->toggleBusy(false);
    this->accept();
}
